%global pypi_name libcnml
%global sum libcnml is a CNML parser library for Python

# Python 3 only for Fedora for now.
%if 0%{?fedora} > 12
%global with_python3 1
%endif

# python-setuptools is needed only in EPEL 7. In Fedora is already required by python package
%if 0%{?el7}
%global needs_python_setuptools 1
%endif

Name:           python-%{pypi_name}
Version:        0.9.5
Release:        7%{?dist}
Summary:        %{sum}

License:        GPLv3
URL:            https://github.com/PabloCastellano/libcnml
Source0:        https://pypi.python.org/packages/source/l/%{pypi_name}/%{pypi_name}-%{version}.tar.gz


BuildArch:      noarch

BuildRequires:  python2-devel
%if 0%{?needs_python_setuptools}
BuildRequires:  python2-setuptools
%endif
# python2-six is missing, see https://bugzilla.redhat.com/show_bug.cgi?id=1342037
BuildRequires:  python2-six
%if 0%{?with_python3}
BuildRequires:  python3-devel
BuildRequires:  python3-six
%endif

%description
Community Network Mark Up Language (CNML) is a project that aims to define
an open ISO standard and scalable for describing mesh clouds,
though it's not limited to this kind of networks and nowadays it's being
used also in point to point infrastructure networks.

CNML is a specification based on XML, which makes it easily extendible
and readable for humans besides of computers. It includes some ideas
from other implementations and previous concepts like nodeXchange and SNDX.

Some advantages of using CNML is that it allows to uncouple different
functionalities independently of the web application used to show the data,
reducing dependence from it and its internal tables of the database.

%package -n python2-%{pypi_name}
Summary:        %{sum}
%{?python_provide:%python_provide python2-%{pypi_name}}
# python2-six is missing, see https://bugzilla.redhat.com/show_bug.cgi?id=1342037
Requires:  python2-six

%description -n python2-%{pypi_name}
Community Network Mark Up Language (CNML) is a project that aims to define
an open ISO standard and scalable for describing mesh clouds,
though it's not limited to this kind of networks and nowadays it's being
used also in point to point infrastructure networks.

CNML is a specification based on XML, which makes it easily extendible
and readable for humans besides of computers. It includes some ideas
from other implementations and previous concepts like nodeXchange and SNDX.

Some advantages of using CNML is that it allows to uncouple different
functionalities independently of the web application used to show the data,
reducing dependence from it and its internal tables of the database.

%if 0%{?with_python3}
%package -n python3-%{pypi_name}
Summary:        %{sum}
%{?python_provide:%python_provide python3-%{pypi_name}}
Requires:		python3-six

%description -n python3-%{pypi_name}
Community Network Mark Up Language (CNML) is a project that aims to define
an open ISO standard and scalable for describing mesh clouds,
though it's not limited to this kind of networks and nowadays it's being
used also in point to point infrastructure networks.

CNML is a specification based on XML, which makes it easily extendible
and readable for humans besides of computers. It includes some ideas
from other implementations and previous concepts like nodeXchange and SNDX.

Some advantages of using CNML is that it allows to uncouple different
functionalities independently of the web application used to show the data,
reducing dependence from it and its internal tables of the database.
%endif # if with_python3

%prep
%setup -q -n %{pypi_name}-%{version}
rm -rf %{pypi_name}.egg-info

%build
%py2_build
%if 0%{?with_python3}
%py3_build
%endif # if with_python3

%install
%py2_install
%if 0%{?with_python3}
%py3_install
%endif # if with_python3

# Disabled tests since they rely on internet connection and Koji does not allow
# internet connection during package creating process. Further informations at
# https://github.com/PabloCastellano/libcnml/issues/18
#%check
#%{__python2} setup.py test
#%if 0%{?with_python3}
#%{__python3} setup.py test
#%endif # if with_python3

%files -n python2-%{pypi_name}
%license LICENSE.txt
%doc README.md
%{python2_sitelib}/*

%if 0%{?with_python3}
%files -n python3-%{pypi_name}
%license LICENSE.txt
%doc README.md
%{python3_sitelib}/*
%endif # if with_python3

%changelog
* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.5-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jan 25 2018 Iryna Shcherbina <ishcherb@redhat.com> - 0.9.5-6
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 0.9.5-3
- Rebuild for Python 3.6

* Tue Jul 19 2016 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.5-2
- https://fedoraproject.org/wiki/Changes/Automatic_Provides_for_Python_RPM_Packages

* Sun Jul 17 2016 Germano Massullo <germano.massullo@gmail.com> - 0.9.5-1
- Minor update

* Thu Jun 02 2016 Germano Massullo <germano.massullo@gmail.com> - 0.9.4-2
- Fixed python six prefix

* Sat Jan 23 2016 Germano Massullo <germano.massullo@gmail.com> - 0.9.4-1
- First commit on Fedora's Git
